# How to generate a PIP package?
- Change setup.cfg version
- py -m build
- py -m twine upload --skip-existing dist/*

Use this api key:
pypi-AgEIcHlwaS5vcmcCJDFlYWM1ODBiLTlhNWUtNDdiYS1iYTE1LTA0NzdkNTRjZDMzMwACKlszLCJkZDE1MTM0Yy1lYmRlLTQzMmEtYTkwNS0wM2E1NGY1ZGYxNWQiXQAABiDJUVw2h3xb1VgjnD_0Jd7dyRmTuK38gLp9NJq1rdkkDA

Reference: https://packaging.python.org/en/latest/tutorials/packaging-projects/